@@ -2,8 +2,8 @@ from sybil_engine.contract.weth import WETH
 from sybil_engine.data.networks import get_ids_chain
 from sybil_engine.data.tokens import get_tokens_for_chain
 
-from web3_wizzard_lib.core.contract.aavecontract import AaveContract
-from web3_wizzard_lib.core.modules.bank.bank import Bank
+from libs.web3_wizzard_lib.core.contract.aavecontract import AaveContract
+from libs.web3_wizzard_lib.core.modules.bank.bank import Bank
 
 
 class Aave(Bank):
