@@ -1,6 +1,6 @@
 from sybil_engine.module.module import Order, Module
 
-from web3_wizzard_lib.core.modules.bridge.coredao_bridge_sub import CoreDaoBridgeSubModule
+from libs.web3_wizzard_lib.core.modules.bridge.coredao_bridge_sub import CoreDaoBridgeSubModule
 
 
 class CoreDaoBridge(Module):
