@@ -1,14 +1,10 @@
-from loguru import logger
 from sybil_engine.data.contracts import get_contracts_for_chain
 from sybil_engine.data.networks import get_chain_instance
 from sybil_engine.domain.balance.tokens import Erc20Token
 from sybil_engine.module.module import Module
-from sybil_engine.utils.accumulator import add_accumulator
-from sybil_engine.utils.utils import ConfigurationException
 from sybil_engine.utils.web3_utils import init_web3
 
-from web3_wizzard_lib.core.contract.gmx_reward_router import GmxRewardRouter
-from web3_wizzard_lib.core.contract.new_rage_contract import NewRageContract
+from libs.web3_wizzard_lib.core.contract.gmx_reward_router import GmxRewardRouter
 
 
 class GMXRewardRouter(Module):
