@@ -3,8 +3,8 @@ from sybil_engine.domain.balance.balance_utils import interval_to_eth_balance
 from sybil_engine.domain.balance.tokens import Erc20Token
 from sybil_engine.utils.retry import retry
 
-from web3_wizzard_lib.core.contract.zerolend_liq_contract import ZeroLendLiqContract
-from web3_wizzard_lib.core.modules.liquidity.pool import Pool
+from libs.web3_wizzard_lib.core.contract.zerolend_liq_contract import ZeroLendLiqContract
+from libs.web3_wizzard_lib.core.modules.liquidity.pool import Pool
 
 
 class ZeroLendLiquidity(Pool):
