@@ -4,7 +4,7 @@ from sybil_engine.data.networks import get_chain_instance
 from sybil_engine.domain.balance.balance import NativeBalance
 from sybil_engine.utils.web3_utils import init_web3
 
-from web3_wizzard_lib.core.utils.sub_module import SubModule
+from libs.web3_wizzard_lib.core.utils.sub_module import SubModule
 
 
 class Battlemon(SubModule):
