@@ -2,7 +2,7 @@ from sybil_engine.contract.send import Send
 from sybil_engine.domain.balance.balance import NativeBalance
 from sybil_engine.utils.app_account_utils import AppAccount
 
-from web3_wizzard_lib.core.modules.nft.nft_submodule import NftSubmodule
+from libs.web3_wizzard_lib.core.modules.nft.nft_submodule import NftSubmodule
 
 
 class LineaCultureWeek2Day1(NftSubmodule):
