@@ -3,8 +3,8 @@ from sybil_engine.data.networks import get_chain_instance
 from sybil_engine.utils.web3_utils import init_web3
 from web3 import Web3
 
-from web3_wizzard_lib.core.contract.octomos import OctomosContract
-from web3_wizzard_lib.core.utils.sub_module import SubModule
+from libs.web3_wizzard_lib.core.contract.octomos import OctomosContract
+from libs.web3_wizzard_lib.core.utils.sub_module import SubModule
 
 
 class Octomos(SubModule):
