@@ -4,7 +4,7 @@ from sybil_engine.utils.package_import_utils import get_all_subclasses, import_a
 
 
 def get_swap_classes():
-    import_all_modules_in_directory("web3_wizzard_lib.core.modules.swap")
+    import_all_modules_in_directory("web3-wizzard-lib.utils.modules.swap")
     return get_all_subclasses(Dex)
 
 swap_facade = SwapFacade(get_swap_classes())
