@@ -2,12 +2,12 @@ import glob
 import importlib
 import os
 
+import web3_wizzard_lib
+
 from sybil_engine.module.modules import *
 from loguru import logger
 from sybil_engine.app import launch_with_data
-from sybil_engine.utils.configuration_loader import load_module_vars
 
-import web3_wizzard_lib.core.modules
 from web3_wizzard_lib.core.modules.swap.swap_list import swap_facade
 import importlib.util
 
@@ -34,6 +34,6 @@ def launch():
     logger.info(Module.__subclasses__())
 
     modules_data = Modules(None, swap_facade)
-    #modules_data = load_module_vars("web3_wizzard_lib.core.modules")['modules_data']
+    #modules_data = load_module_vars("web3-wizzard-lib.utils.modules")['modules_data']
 
     launch_with_data(modules_data)
